<?php  if ( ! defined('BASEPATH')) exit('No direct script access allowed');

/**
 * Default Extension
 *
 * @package     Default module
 * @category    Modules
 * @author      Rein de Vries <info@reinos.nl>
 * @link        http://reinos.nl
 * @copyright   Copyright (c) 2013 Reinos.nl Internet Media
 */

/**
 * Include the config file
 */
require_once PATH_THIRD.'relationship_field_links/config.php';
 
class Relationship_field_links_ext 
{   
    
    public $name            = RLINKS_NAME;
    public $description     = RLINKS_DESCRIPTION;
    public $version         = RLINKS_VERSION;
    public $settings        = array();
    public $docs_url        = RLINKS_DOCS;
    public $settings_exist  = 'n';
    //public $required_by   = array(DEFAULT_NAME);
    
    /**
     * Constructor
     *
     * @param   mixed   Settings array or empty string if none exist.
     */
    function __construct($settings = '')
    {
        $this->settings = $settings;

        //theme url
        //$theme_url = PATH_THEMES.'third_party/'.RLINKS_MAP.'/';

        
    }

    /**
    * Activate Extension
    *
    * This function enters the extension into the exp_extensions table
    *
    * @see http://codeigniter.com/user_guide/database/index.html for
    * more information on the db class.
    *
    * @return void
    */
    function activate_extension()
    {
        $data = array(
            'class'     => __CLASS__,
            'method'    => 'publish_form_entry_data',
            'hook'      => 'publish_form_entry_data',
            'settings'  => serialize($this->settings),
            'priority'  => 10,
            'version'   => $this->version,
            'enabled'   => 'y'
        );

        ee()->db->insert('extensions', $data);

        $data = array(
            'class'     => __CLASS__,
            'method'    => 'sessions_start',
            'hook'      => 'sessions_start',
            'settings'  => serialize($this->settings),
            'priority'  => 1,
            'version'   => $this->version,
            'enabled'   => 'y'
        );

        ee()->db->insert('extensions', $data);
    }

    /**
    * Update Extension
    *
    * This function performs any necessary db updates when the extension
    * page is visited
    *
    * @return  mixed   void on update / false if none
    */
    function update_extension($current = '')
    {
        if ($current == '' OR $current == $this->version)
        {
            return FALSE;
        }

        ee()->db->where('class', __CLASS__);
        ee()->db->update(
            'extensions',
            array('version' => $this->version)
        );
    }

    /**
    * Disable Extension
    *
    * This method removes information from the exp_extensions table
    *
    * @return void
    */
    function disable_extension()
    {
        ee()->db->where('class', __CLASS__);
        ee()->db->delete('extensions');
    }

    /**
    * sessions_start method
    *
    * Allows modification of entry data for the publish form when editing an existing entry.
    *
    * @param int $entry_id
    * @param object $entry_trash 
    * @return void
    */
    function sessions_start($ee)
    {
        //set the session to the var
        ee()->session = $ee;
        
        //is the first segment 'entry_api'
        $is_relationship_links = ee()->uri->segment(1) == 'relationship_field_links' ? true : false;
        $entry_id = ee()->uri->segment(2);
        
        //is the request a page and is the first segment entry_api?
        //than we need to trigger te services
        if (REQ == 'PAGE' && $is_relationship_links && !empty($ee) && !empty($entry_id))
        {
            $q = ee()->db->select('title')->from('channel_titles')->where('entry_id', $entry_id)->get()->row();
            echo $q->title;
            exit;   
        }

    }

    /**
    * publish_form_entry_data method
    *
    * Allows modification of entry data for the publish form when editing an existing entry.
    *
    * @param int $entry_id
    * @param object $entry_trash 
    * @return void
    */
    function publish_form_entry_data($data)
    {
        //ee()->cp->load_package_js('relationship_links');

        $js = <<<EOF
            <script type="text/javascript">
            $(function(){
                if($('.multiselect').length > 0) {
                    setTimeout(function(){
                        $('.multiselect li').each(function(){
                            var entry_id = $(this).find('label [type="checkbox"]').attr('value');
                            $(this).append('<a data-entryid="'+entry_id+'" class="rel_dialog" href="'+EE.BASE+'&C=content_publish&M=entry_form&entry_id='+entry_id+'">edit</a>');
                        
                            //add click events 
                            $('.rel_dialog').on('click', function(e){
                                e.stopPropagation();
                                e.stopImmediatePropagation();
                                e.preventDefault();

                                var win;
                                var win = window.open($(this).attr('href')+'#new_window', 'rel_window');
                                var entry_id = $(this).data('entryid');
                                var obj = $(this);

                                //window close, we need to update the title if needed
                                var intervalId = setInterval(function() {
                                    if (win.closed) {
                                        clearInterval(intervalId);
                                        //get the title of the entry
                                        $.get('/relationship_field_links/'+entry_id, function(new_title){
                                           // obj.parent().find('label').text(new_title);
                                        });
                                    }
                                }, 200);

                                return false;
                            });
                        });
                        
                        $('.rel_dialog').css({
                            position: 'absolute',
                            right: '10px',
                            top: '8px',
                            zIndex : 9999
                        });
                    }, 500);

                    //add dialog box
                    $('body').append('<div id="rel_dialog"></a>');

                    
                }

                //check if the url is called in a new window.
                //then we need to ajax 
                if(location.hash == '#new_window') {
                    var entry_id = $(this).data('entryid');
                    var options = { 
                        //target:        '#submit_button',   // target element(s) to be updated with server response 
                        //beforeSubmit:  showRequest,  // pre-submit callback 
                        success:       function(){
                            window.close();
                        }  // post-submit callback 
                 
                        // other available options: 
                        //url:       url         // override for form's 'action' attribute 
                        //type:      type        // 'get' or 'post', override for form's 'method' attribute 
                        //dataType:  null        // 'xml', 'script', or 'json' (expected server response type) 
                        //clearForm: true        // clear all form fields after successful submit 
                        //resetForm: true        // reset the form after successful submit 
                 
                        // $.ajax options can be used here too, for example: 
                        //timeout:   3000 
                    }; 
                 
                    // bind to the form's submit event 
                    $('#publishForm').submit(function() { 
                        // inside event callbacks 'this' is the DOM element so we first 
                        // wrap it in a jQuery object and then invoke ajaxSubmit 
                        $(this).ajaxSubmit(options); 
                 
                        // !!! Important !!! 
                        // always return false to prevent standard browser submit and page navigation 
                        return false; 
                    }); 
                }
            });

        </script>
EOF;
        ee()->cp->add_to_foot($js);
            
        return $data;
    }

}
// END CLASS

/* End of file ext.default.php */
/* Location: /system/expressionengine/third_party/default/ext.default.php */